#!/bin/csh

set dir = /Users/sean/Documents/Research/NorCalQ/
set infile1 = $dir/Calc2Sta/sacvelZ.lst
set datadir = $dir/Data/WaveformBHBK/SacVel
set outfile1 = printhdr.out
set outfile2 = outfile.out
set outfile3 = printhdr_uniq.out
set outfile4 = filtazdist.out

set vlgmin = 2.6
set vlgmax = 3.5
set vlgave = 3.5
set snr = 2
set gamma = 0.5
set mindist = 100
set maxdist = 400
set mininter = 50
set maxinter = 500
set delaz = 15

#---------------------------------------------------------#
# Find record az and dist info
if 1 then

echo START >! $outfile1
echo START >! $outfile2

set file = ` cat $infile1 `

@ i = 1
while ( $i <= $#file )

set sacfile = $file[$i]

cp $datadir/$sacfile .

sac << FIN >! sac.out
r $sacfile
message " OUT= $sacfile &1,stla &1,stlo &1,az &1,dist "
FIN

grep OUT= sac.out | cut -d= -f2- >> $outfile1

\rm $sacfile

@ i++
end

endif

#---------------------------------------------------------#
# Find sta-evt dist and az info
if 1 then

set evid = ` cut -d. -f1 $outfile1 | sort | uniq `

@ i = 1
while ( $i <= $#evid )

set id = $evid[$i]

grep $id $outfile1 >! file.tab

set sta = ` cut -d. -f2 file.tab `
set slat = ` awk '{printf "%.2f\n", $2}' file.tab `
set slon = ` awk '{printf "%.2f\n", $3}' file.tab `
set az = ` awk '{printf "%.2f\n", $4}' file.tab `
set dist = ` awk '{printf "%.2f\n", $5}' file.tab `

@ j = 1
while ( $j <= $#sta )

@ k = 1
while ( $k <= $#sta )

set azdiff = ` echo $az[$j]  $az[$k] | awk '{print ( $1 - $2 )}' `
distaz << FIN >! distaz.out
$slat[$j] $slon[$j]
$slat[$k] $slon[$k]
FIN
set distdiff = ` grep distkm distaz.out | awk '{print $3}' `

echo " $id $sta[$j] $sta[$k] $dist[$j] $dist[$k] $distdiff $az[$j] $az[$k] $azdiff " >> $outfile2

@ k++
end

@ j++
end

@ i++
end

endif

#---------------------------------------------------------#
# Filter file for specific requirements
if 1 then

awk '$6 > 0.001 {print $0, $1, ($9 * $9)}' $outfile2 | sort -k10,11 | uniq -f9 | cut -d" " -f1-10 >! $outfile3

awk '$9 <= '$delaz' && $9 >= (-1 * '$delaz') && $4 >= '$mindist' && $4 <= '$maxdist' && $5 >= '$mindist' && $5 <= '$maxdist' && $6 >= '$mininter' && $6 <= '$maxinter' {print $0}' $outfile3 >! $outfile4

endif

#---------------------------------------------------------#
# Calculate spectral ratio
if 0 then

set evid = ` awk '{print $1}' $outfile4 `
set stnm1 = ` awk '{print $2}' $outfile4 `
set stnm2 = ` awk '{print $3}' $outfile4 `

@ i = 1
while ( $i <= $#evid )

set sacfile1 = $evid[$i].$stnm1[$i].BHZ.vel.sac
set sacfile2 = $evid[$i].$stnm2[$i].BHZ.vel.sac

if ( -e $datadir/$sacfile1 && -e $datadir/$sacfile2 ) then
cp $datadir/$sacfile1 .
cp $datadir/$sacfile2 .

sac << FIN >! sac.out
echo on
macro calc2sta.mac sacfile1 $sacfile1 sacfile2 $sacfile2 vlgmin $vlgmin vlgmax $vlgmax vlgave $vlgave gamma $gamma snr $snr
quit
FIN

grep SNR= sac.out | cut -d= -f2-
grep ERROR sac.out
grep NPTS1 sac.out | cut -d= -f2- >> npts1.out
grep NPTS2 sac.out | cut -d= -f2- >> npts2.out

if ( -e D.sac.am ) then
  echo Moving D.sac.am to $evid[$i].$stnm1[$i].$stnm2[$i].D.sac.am
  mv D.sac.am $evid[$i].$stnm1[$i].$stnm2[$i].D.sac.am
else
  echo D.sac.am does not exist
endif

\rm $sacfile1 $sacfile2

else
  echo $sacfile1 or $sacfile2 does not exist
endif

@ i++
end

endif

#---------------------------------------------------------#
# Stack the ratios
if 0 then

ls *.D.sac.am | sort -t. -k2,3 | uniq -c -s14 >! stack.lst
set stacknum = ` awk '{print $1}' stack.lst `
set match = ` cut -c20- stack.lst `

@ i = 1
while ( $i <= $#match )

set file = ` awk 'NR==2 {print $2}' stack.lst `

sac << FIN >! sac.out
r $file
funcgen line 0 0 delta &1,delta npts &1,npts begin &1,b
w zeroline.sac
quit
FIN

set sacfile = ` ls *.$match[$i] `

@ j = 1
while ( $j <= $#sacfile )

sac << FIN >! sac.out
r zeroline.sac
addf $sacfile[$j]
w zeroline.sac
quit
FIN

@ j++
end

sac << FIN >! sac.out
r zeroline.sac
div $#sacfile
w STASTACK.$stacknum[$i].$match[$i]
quit
FIN

@ i++
end

ls STASTACK*.D.sac.am | cut -d. -f1-5 >! stackfile.lst

endif
