% 1-D model power-law model using matched stations/paths
% Linearize model by going to log domain
%
% Weights are from variance in Q(f) measurements for each station
% Model is log(Qlg) = log(Qo) + a log(f)
Ulg = 3.5;

staname = char('PKD');
freq = [0.375 0.75 1.5 3];

stanum = size(staname,1);
freqnum = length(freq);

for stai = 1:stanum
    Qinv = NaN*ones(freqnum,1);
    Qinvse = NaN*ones(freqnum,1);
    freqmid = NaN*ones(freqnum,1);
    data = load([deblank(staname(stai,:)) '.dat']);
    for freqi = 1:freqnum
        freqpow = log((2/3)*freq(freqi))/log(2);
        freqindex = find(data(:,1) == freqpow);
        datan = data(freqindex,2:3);

        if length(datan) > 2
            % LHS vs distance slope
            [p,stats] = robustfit(datan(:,1),datan(:,2),'bisquare');

            % Plot it
            figure
            plot(datan(:,1),datan(:,2),'.'); lsline; hold on
            plot(datan(:,1),p(1)+p(2)*datan(:,1)); hold off

            % slope and slope SE
            m = p(2);
            mse = stats.se(2);

            % Calculate inverse Q
            qi = (-1*Ulg*m)/(pi*freq(freqi));
            Qinv(freqi) = qi;

            qimax =  (-1*Ulg*(m-mse))/(pi*freq(freqi));
            qise = qimax-qi;
            Qinvse(freqi) = qise;

            freqmid(freqi) = freq(freqi);
            if (qi <= 0)
                Qinv(freqi) = NaN;
                Qinvse(freqi) = NaN;
                freqmid(freqi) = NaN;
            end

            % Output some stuff
            save([deblank(staname(stai,:)) '.' num2str(freqi) '.pts.dat'],'datan','-ascii');
            save([deblank(staname(stai,:)) '.' num2str(freqi) '.lin.dat'],'p','-ascii');
            fqe = [freqmid(freqi) Qinv(freqi) Qinvse(freqi)];
            save([deblank(staname(stai,:)) '.' num2str(freqi) '.fqe.dat'],'fqe','-ascii');

        end

    end

    % Data vector
    d = Qinv;
    ld = log10(d);

    % Weight vector (standard dev)
    se = Qinvse;
    dmax = d+se;
    ldmax = log10(dmax);
    lQinvse = ldmax - ld;
    lw = 1./(lQinvse.^2);

    % Freq vector
    f = freqmid;
    lf = log10(f);

    % Get rid of NaN
    ldi = find(~isnan(ld)); ldn = ld(ldi);
    lfi = find(~isnan(lf)); lfn = lf(lfi);
    lwi = find(~isnan(lw)); lwn = lw(lwi);

    % Model matrix
    Gn = [(0*lfn)+1 lfn];

    % Invert
    %m = inv(Gn'*diag(lwn)*Gn)*Gn'*diag(lwn)*ldn;
    m = lscov(Gn,ldn,lwn);

    % Calculate weighted values
    %ldnp = diag(sqrt(lwn))*ldn;
    %Gnp = diag(sqrt(lwn))*Gn;

    % Bootstrap to find confidence interval
    nsets = 1000;
    estldn = m(1)+(m(2)*lfn);
    resldn = ldn-estldn;
    %rerr = normrnd(0,(10/nsets),[4 nsets]);
    %rerr = normrnd(0,0,[4 nsets]);
    [out,sam] = bootstrp(nsets,[],resldn);
    mbs = NaN*ones(2,nsets);
    for i = 1:nsets
        mbs(:,i) = lscov(Gn,estldn+resldn(sam(:,i)),lwn(sam(:,i)));
    end

    % Create covariance matrix from bootstrap results
    mnorm = repmat(m,1,nsets) - mbs;
    Cov = (1/nsets)*(mnorm*mnorm');

    % Create confidence region from covariance matrix
    n=100; p=0:pi/n:2*pi;
    [eigvec,eigval] = eig(Cov);
    xy = [cos(p'),sin(p')] * sqrt(eigval) * eigvec'; % Transformation
    x = xy(:,1);
    y = xy(:,2);

    k = sqrt(chi2inv(0.95,2));
    k = 1;
    x = m(1)+(k*x);
    y = m(2)+(k*y);
    E = [x y];

    %figure
    %errorbar(f,d,w); set(gca,'XScale','log','YScale','log'); xlim([0.1 10]);
    figure
    plot(lf,ld,'ob',lf,m(1)+m(2).*lf);

    figure
    plot(10.^-mbs(1,:),-mbs(2,:),'+b',10.^-m(1),-m(2),'xr',10.^-x,-y,'-k'); xlim([0 500]); ylim([0 2]);

    qo = 10^-m(1); qose = std(10.^-mbs(1,:));
    qoinv = 10^m(1); qoinvse = std(10.^mbs(1,:));
    n = -m(2); nse = std(-mbs(2,:));
    qfn = [qo n qose nse; qoinv n qoinvse nse; m(1) m(2) std(mbs(1,:)) std(mbs(2,:))];
    mbsout = [mbs(1,:)' mbs(2,:)'];
    ell = [x y];
    fqw = [lfn ldn lwn];
    save([deblank(staname(stai,:))  '.qfn.dat'],'qfn','-ascii');
    save([deblank(staname(stai,:))  '.pts.dat'],'mbsout','-ascii');
    save([deblank(staname(stai,:))  '.ell.dat'],'ell','-ascii');    
    save([deblank(staname(stai,:))  '.fqw.dat'],'fqw','-ascii');    

    close all
end
