#!/bin/csh

# Master directory
set dir = .
# List of SAC files to operate on
set infile1 = $dir/EXAMPLE/sacvelZ.lst
# Directory of instrument-deconvolved to ground velocity SAC files
set datadir = $dir/EXAMPLE/SacVel

# Output files required for the sorting
set outfile1 = printhdr.out
set outfile2 = outfile.out
set outfile3 = printhdr_uniq.out
set outfile4 = filtazdist.out
set outfile5 = stacount.out
set outfile6 = reclist.lst
set outfile7 = stapair.tab

# Lg Parameters
set vlgmin = 2.6
set vlgmax = 3.5
set vlgave = 3.5
set snr = 2
set gamma = 0.5
set mindist = 100
set maxdist = 400
set mininter = 50
set maxinter = 500
set delaz = 15

# The whole first parts find data from the given list
# that fit the azimuth window criteria for 2-station and
# 2-event setup

#---------------------------------------------------------#
# Find record az and dist info
if 1 then

echo START >! $outfile1

set file = ` cat $infile1 `

@ i = 1
while ( $i <= $#file )

set sacfile = $file[$i]

cp $datadir/$sacfile .

sac << FIN >! sac.out
r $sacfile
message " OUT= $sacfile &1,stla &1,stlo &1,az &1,dist "
FIN

grep OUT= sac.out | cut -d= -f2- >> $outfile1

\rm $sacfile

@ i++
end

endif
#---------------------------------------------------------#
# Find sta-evt dist and az info
if 1 then

echo START >! $outfile2

set evid = ` cut -d. -f1 $outfile1 | sort | uniq `

@ i = 1
while ( $i <= $#evid )

set id = $evid[$i]

grep $id $outfile1 >! file.tab

set sta = ` cut -d. -f2 file.tab `
set slat = ` awk '{printf "%.2f\n", $2}' file.tab `
set slon = ` awk '{printf "%.2f\n", $3}' file.tab `
set az = ` awk '{printf "%.2f\n", $4}' file.tab `
set dist = ` awk '{printf "%.2f\n", $5}' file.tab `

@ j = 1
while ( $j <= $#sta )

@ k = 1
while ( $k <= $#sta )

set azdiff = ` echo $az[$j]  $az[$k] | awk '{print ( $1 - $2 )}' `
distaz << FIN >! distaz.out
$slat[$j] $slon[$j]
$slat[$k] $slon[$k]
FIN
set distdiff = ` grep distkm distaz.out | awk '{print $3}' `

echo " $id $sta[$j] $sta[$k] $dist[$j] $dist[$k] $distdiff $az[$j] $az[$k] $azdiff " >> $outfile2

@ k++
end

@ j++
end

@ i++
end

endif
#---------------------------------------------------------#
# Filter file for specific requirements
if 1 then

awk '$6 > 0.001 {print $0, $1, ($9 * $9)}' $outfile2 | sort -k10,11 | uniq -f9 | cut -d" " -f1-10 >! $outfile3

awk '$9 <= '$delaz' && $9 >= (-1 * '$delaz') && $4 >= '$mindist' && $4 <= '$maxdist' && $5 >= '$mindist' && $5 <= '$maxdist' && $6 >= '$mininter' && $6 <= '$maxinter' {print $0}' $outfile3 >! $outfile4

endif
#---------------------------------------------------------#
# Find station pairs for each event
if 1 then

echo START >! $outfile5

awk '{print $0, $2, $3}' $outfile4 | sort -k 10,11 | uniq -f 9 -c >! out1.out
set sta1 = ` awk '$1 > 1 {print $11}' out1.out `
set sta2 = ` awk '$1 > 1 {print $12}' out1.out `

@ i = 1
while ( $i <= $#sta1 )

set stnm1 = $sta1[$i]
set stnm2 = $sta2[$i]

set count1 = ` awk '$2 ~ /'$stnm1'/ && $3 ~ /'$stnm2'/ && $4 < $5 {print $0}' $outfile4 | wc -l | awk '{print $1}'  `
set count2 = ` awk '$2 ~ /'$stnm1'/ && $3 ~ /'$stnm2'/ && $4 > $5 {print $0}' $outfile4 | wc -l | awk '{print $1}'  `

echo $sta1[$i] $count1 $sta2[$i] $count2 >> $outfile5

@ i++
end

awk '$2 > 0 && $4 > 0 {print $0}' $outfile5 >! $outfile7

set sta1 = ` awk '$2 > 0 && $4 > 0 {print $1}' $outfile5 `
set sta2 = ` awk '$2 > 0 && $4 > 0 {print $3}' $outfile5 `

@ j = 1
while ( $j <= $#sta1 )

set stnm1 = $sta1[$j]
set stnm2 = $sta2[$j]

awk '$2 ~ /'$stnm1'/ && $3 ~ /'$stnm2'/ {print $1"."$2".BHZ.vel.sac"}' $outfile4 >> out2.out
awk '$2 ~ /'$stnm1'/ && $3 ~ /'$stnm2'/ {print $1"."$3".BHZ.vel.sac"}' $outfile4 >> out2.out

@ j++
end

sort out2.out | uniq >! $outfile6
 
\rm out?.out

endif
#---------------------------------------------------------#
# Calculate spectral ratio
if 1 then

set stnm1 = ` awk '{print $1}' $outfile7 `
set stnm2 = ` awk '{print $3}' $outfile7 `

@ i = 1
while ( $i <= $#stnm1 )

set sta1 = $stnm1[$i]
set sta2 = $stnm2[$i]

awk '$2 ~ /'$sta1'/ && $3 ~ /'$sta2'/ && $4 < $5 {print $0}' $outfile4 >! stapairlt.tmp
awk '$2 ~ /'$sta1'/ && $3 ~ /'$sta2'/ && $4 > $5 {print $0}' $outfile4 >! stapairmt.tmp

set evid1 = ` awk '{print $1}' stapairlt.tmp `
set evid2 = ` awk '{print $1}' stapairmt.tmp `

@ j = 1
while ( $j <= $#evid1 )

set sacfile1 = $evid1[$j].$sta1.BHZ.vel.sac
set sacfile2 = $evid1[$j].$sta2.BHZ.vel.sac

if ( ( -e $datadir/$sacfile1 ) && ( -e $datadir/$sacfile2 ) ) then

cp $datadir/$sacfile1 .
cp $datadir/$sacfile2 .

@ k = 1
while ( $k <= $#evid2 )

set sacfile3 = $evid2[$k].$sta1.BHZ.vel.sac
set sacfile4 = $evid2[$k].$sta2.BHZ.vel.sac

if ( ( -e $datadir/$sacfile3 ) && ( -e $datadir/$sacfile4 ) ) then

cp $datadir/$sacfile3 .
cp $datadir/$sacfile4 .

sac << FIN >! sac.out
macro calcrev2sta.mac sacfile1 $sacfile1 sacfile2 $sacfile2 sacfile3 $sacfile3 sacfile4 $sacfile4 vlgave $vlgave vlgmin $vlgmin vlgmax $vlgmax snr $snr gamma $gamma
quit
FIN

grep SNR= sac.out | cut -d= -f2-
grep ERROR sac.out

if ( -e gamma.sac.am ) then
  echo Moving gamma.sac.am to $evid1[$j].$evid2[$k].$sta1.$sta2.gamma.sac.am
  mv gamma.sac.am $evid1[$j].$evid2[$k].$sta1.$sta2.gamma.sac.am
else
  echo gamma.sac.am does not exist
endif

\rm $sacfile3 $sacfile4

else
  echo $sacfile3 or $sacfile4 does not exist
endif

@ k++
end

else
  echo $sacfile1 or $sacfile2 does not exist
endif

\rm $sacfile1 $sacfile2

@ j++
end

@ i++
end

endif
#---------------------------------------------------------#