% Implements Reverse 2-station method

% Requires SacLab (www.aeic.alaska.edu/input/mthorne/software)

% Find best fit 1-D model for all data
warning off all

unix('ls *.gamma.sac.am > stack.lst');
unix('cut -d. -f1-4 stack.lst > path.lst');
stacklist = 'stack.lst';
pathlist = 'path.lst';
stackid = fopen(stacklist);
pathid = fopen(pathlist);
pathname = textscan(pathid,'%s');
pathi = 0;
while feof(stackid) == 0
    pathi = pathi+1;
    sacname = fgetl(stackid);
    stack = rsac(sacname);

    data = stack(:,2)';
    freq = stack(:,1)';

    downfac = lh(stack,'USER3')

    data = decimate(data,downfac);
    freq = decimate(freq,downfac);

    % Perform nonlinear fit
    [p,pres,pJ] = nlinfit(freq,data,@powerlaw1,[100 0.5]);
    dfit = (1/p(1))*freq.^(1-p(2));
    %dres = dfit - data;

    % Solve for parameters
    qo = p(1);
    n = p(2);

    if ( (qo > 0 & qo < 1000) & (n > 0 & n < 10) )
        % Covariance matrix and error ellipse from bootstrap
        nsets = 1000;
        pdistr = bootstrp(nsets, @(bootr) nlinfit(freq,dfit+bootr',@powerlaw1,[100 0.5]), pres);
        pnorm = repmat(p,nsets,1) - pdistr;
        Cov = (1/nsets)*(pnorm'*pnorm);

        % SE from bootstrap
        disp(sacname);
        qose = std(pdistr(:,1));
        nse = std(pdistr(:,2));

        % SE from matlab
        ci = nlparci(p,pres,pJ);

        % Create confidence region from covariance matrix
        v1=100; v2=0:pi/v1:2*pi;
        [eigvec,eigval] = eig(Cov);
        xy = [cos(v2'),sin(v2')] * sqrt(eigval) * eigvec'; % Transformation
        x = xy(:,1);
        y = xy(:,2);

        k = sqrt(chi2inv(0.95,2));
        k = 1;
        x = p(1)+(k*x);
        y = p(2)+(k*y);
        E = [x y];

        qon = [qo n qose nse ci(1,:) ci(2,:)]
        pts = [freq' data'];
        save([char(pathname{1}(pathi)) '.qon'], 'qon', '-ascii');
        save([char(pathname{1}(pathi)) '.pts'], 'pts', '-ascii');

        bootpts = [pdistr(:,1) pdistr(:,2)];
        ell = [x y];
        save([char(pathname{1}(pathi)) '.btp'], 'bootpts', '-ascii');
        save([char(pathname{1}(pathi)) '.ell'], 'ell', '-ascii');

        %figure
        %subplot(2,1,1); loglog(freq,data,'xb',freq,dfit,'-k'); title(sacname);
        %subplot(2,1,2); plot(pdistr(:,1),pdistr(:,2),'.',x,y,'-k'); xlim([0 300]); ylim([0 1]);
    else
        disp([sacname ' values < 0']);
    end
end

fclose(stackid);
fclose(pathid);