#!/bin/csh

# Master directory
set dir = .
# List of SAC files to operate on
set infile = $dir/EXAMPLE/sacvelN.lst
# Directory of instrument-deconvolved to ground velocity SAC files
set datadir = $dir/EXAMPLE/SacVel
# Directory of coda-source spectra text files
set codadir = $dir/EXAMPLE/CodaSpectra

# Lg Parameters
set vlgmin = 2.6
set vlgmax = 3.5
set vlgave = 3.5
set snr = 2
set gamma = 0.5
set mindist = 100
set maxdist = 400

# Source radiation parameters (used in calcsource.mac)
set rhor = 2600
set rhos = 2600
set radp = 0.60
set vr = 3.0
set vs = 3.0

# Go through each file in the list
set file = ` cut -d. -f1-2 $infile `
set evid = ` cut -d. -f1 $infile `

@ i = 1
while ( $i <= $#file )

set sacfileN = $file[$i].BHN.vel.sac
set sacfileE = $file[$i].BHE.vel.sac
set sourcefile = Spectra.avg.$evid[$i].dat

# Test to see if we have coda spectra for the event
if ( -e $codadir/$sourcefile ) then
  cp $codadir/$sourcefile .

  if ( -e $datadir/$sacfileN && -e $datadir/$sacfileE ) then
    cp $datadir/$sacfileN .
    cp $datadir/$sacfileE .

# Run SAC macro
sac << FIN >! sac.out
echo on
macro calcsource.mac sacfilen $sacfileN sacfilee $sacfileE sourcefile $sourcefile vlgmin $vlgmin vlgmax $vlgmax gamma $gamma vlgave $vlgave rhor $rhor rhos $rhos radp $radp vr $vr vs $vs mindist $mindist maxdist $maxdist
quit
FIN

# Test to see if there was output from the SAC macro and reformat
# the ascii file output to columns
    if ( -e Q.saca ) then
      awk 'NR >= 31 {print $1RS$2RS$3RS$4RS$5}' Q.saca >! valfile
# Make a column file of midfreq Q SNR (uses output from 
# formatsource.csh which was run in calcsource.mac
      paste patfile valfile snrfile >! $file[$i].dat
      echo $file[$i].dat

      \rm Q.saca
    else
      echo Q.saca does not exist
    endif

    \rm $sacfileN $sacfileE

  else
    echo SAC file does not exist
  endif

  \rm $sourcefile

else
  echo source file does not exist
endif

@ i++
end