% Find best fit 1-D model for all data
warning off all

staname = char('PKD');

%type = 'bisquare';
type = 'ols';

stanum = size(staname,1);

for stai = 1:stanum
    disp([num2str(stai) ' of ' num2str(stanum)]);
    eval(['ls *.' deblank(staname(stai,:)) '.dat > file.lst']);
    unix('cut -d. -f1 file.lst > evt.lst');
    evt = load('evt.lst');
    filelist = 'file.lst';
    fileid = fopen(filelist);
    Pout = NaN * ones(length(evt),4);
    evti = 0;
    while feof(fileid) == 0
        evti = evti+1;

        filename = fgetl(fileid);
        data = load(filename);
        % Evaluate the correct frequencies
        freqmin = 0.5;
        freqmax = 8;
        freqi = find((data(:,1) >= freqmin) & (data(:,1) <= freqmax));
        dataf = data(freqi,:);
        % Find where snr (3rd column) is greater than 2
        snri = find(dataf(:,3) > 2);
        datas = dataf(snri,:);

        % Make sure 0 < Q < 5000
        qi = find((datas(:,2) > 0) & (datas(:,2) < 5000));
        datan = datas(qi,:);

        disp(filename)
        [length(datan) length(datas)]

        if (length(qi) > 3)

            freq = datan(:,1);
            q = datan(:,2);

            % Perform iterative fit
            [p,pse] = robustfit(log10(freq),log10(q),type);
            lqfit = p(1) + (p(2)*log10(freq));
            resid = log10(q) - lqfit;

            % Calculate correlation
            [R,P] = corrcoef(lqfit,log10(q));
            Pout(evti,:) = [p' R(1,2) P(1,2)]; % For later comparison

            if ((R(1,2) > 0) & (P(1,2) <= 0.1) & (p(2) > 0))

                % Output fitted parameters
                qo = 10^p(1); n = p(2);  

                % SE from covariance matrix
                qose = (10^(p(1) + pse.se(1))) - qo;
                nse = pse.se(2)

                % Covariance matrix and error ellipse from bootstrap
                nsets = 1000;
                pdistr = bootstrp(nsets, @(bootr) robustfit(log10(freq),lqfit+bootr,type), resid);
                pnorm = repmat(p',nsets,1) - pdistr;
                Cov = (1/nsets)*(pnorm'*pnorm);

                % SE from bootstrap
                qose = std(10.^pdistr(:,1));
                nse = std(pdistr(:,2))

                % Create confidence region from covariance matrix
                v1=100; v2=0:pi/v1:2*pi;
                [eigvec,eigval] = eig(Cov);
                xy = [cos(v2'),sin(v2')] * sqrt(eigval) * eigvec'; % Transformation
                x = xy(:,1);
                y = xy(:,2);

                k = sqrt(chi2inv(0.95,2));
                k = 1;
                x = p(1)+(k*x);
                y = p(2)+(k*y);
                E = [x y];

                pse = [p(1) p(2) pse.se(1) pse.se(2)];
                pts = [freq q];
                save([num2str(evt(evti)) '.' deblank(staname(stai,:)) '.pse'], 'pse', '-ascii');
                save([num2str(evt(evti)) '.' deblank(staname(stai,:)) '.pts'], 'pts', '-ascii');

                qfn = [qo n qose nse];
                %pts = [10.^pnorm(:,1) pnorm(:,2)];
                ell = [10.^x y];
                save([num2str(evt(evti)) '.' deblank(staname(stai,:)) '.qfn'], 'qfn', '-ascii');
                %save([num2str(evt(evti)) '.' deblank(staname(stai,:)) '.pts'], 'pts', '-ascii');
                save([num2str(evt(evti)) '.' deblank(staname(stai,:)) '.ell'], 'ell', '-ascii');

                %figure
                %subplot(2,1,1); plot(log10(freq),log10(q),'xb',log10(freq),lqfit,'-k'); title(filename);
                %subplot(2,1,2); plot(10.^x,y); xlim([0 300]); ylim([0 1]);
            else
                disp('no correlation');
            end

        else
            disp('lt 3 pts');
        end

    end
    fclose(fileid)
 end
