% 1-D model power-law model using matched stations/paths
% Linearize model by going to log domain
%
% Weights are from variance in Q(f) measurements for each station
% Model is log(Qlg) = log(Qo) + a log(f)
Ulg = 3.5;
type = 'ols';

%dirname = char('Norm3','Test1','Test2','Test3','Test4');
dirname = char('Test4');

dirnum = size(dirname,1);

for diri = 1:dirnum
    eval(['cd ./' deblank(dirname(diri,:))]);
    pathlist = 'catfile.lst';
    
    unix('cut -d. -f3-4 catfile.lst > path.lst');
    pathid = fopen('path.lst');
    
    fid = fopen(pathlist);
    pathi = 0;
    while feof(fid) == 0
        pathi = pathi+1;
        fname = fgetl(fid);
        pathname = fgetl(pathid);
        data = load(fname);
        if (diri==3)
            freq = [0.375 0.75 1.5 3];
        else
            freq = [0.75 1.5 3 6];
        end
        Qinv = NaN*ones(length(freq),1);
        Qinvse = NaN*ones(length(freq),1);
        freqmid = NaN*ones(length(freq),1);
        for freqi = 1:length(freq)
            freqpow = log((2/3)*freq(freqi))/log(2);
            freqindex = find(data(:,1) == freqpow);
            
            A1 = data(freqindex,2);
            A2 = data(freqindex,3);
            A3 = data(freqindex,4);
            A4 = data(freqindex,5);
            
            dist1 = data(freqindex,6);
            dist2 = data(freqindex,7);
            dist3 = data(freqindex,8);
            dist4 = data(freqindex,9);
            
            arc1 = data(freqindex,10);
            arc2 = data(freqindex,11);
            arc3 = data(freqindex,12);
            arc4 = data(freqindex,13);
            
            T1 = (A2.*A4)./(A1.*A3);
            T2 = ((dist2.*dist4)./(dist1.*dist3)).^(0.5);
            T3 = ((sind(arc2).*sind(arc4))./(sind(arc1).*sind(arc3))).^(0);
            
            D = (dist2 - dist1) + (dist4 - dist3);
            
            Y = log(T1.*T2.*T3);
            
            %if (diri==2)
            %    lny = data(freqindex,4);
            %else
            %    lny = data(freqindex,3);
            %end
            if length(D) > 2

                % LHS vs D
                [p,stats] = robustfit(D,Y,type);
                pfit = p(1) + (p(2)*D);

                % Plot it
                %figure
                %plot(D,Y,'.'); lsline; hold on
                %plot(D,p(1)+p(2)*D); hold off

                % slope and slope SE
                m = p(2);
                mse = stats.se(2);

                % Calculate inverse Q
                qi = (-Ulg*m)/(pi*freq(freqi));
                Qinv(freqi) = qi;

                qimax =  (-1*Ulg*(m-mse))/(pi*freq(freqi));
                qise = qimax-qi;
                Qinvse(freqi) = qise;

                freqmid(freqi) = freq(freqi);
                
                [R,P] = corrcoef(pfit,Y);
                [R(1,2) P(1,2)]
                %Pout(pathi,:) = [p' R(1,2) P(1,2)]; % For later comparison

                if ((R(1,2) < 0) | (P(1,2) >= 0.1) | (qi <= 0))
                    Qinv(freqi) = NaN;
                    Qinvse(freqi) = NaN;
                    freqmid(freqi) = NaN;
                end

                % Output some stuff
                datout = [D Y];
                fqe = [freqmid(freqi) Qinv(freqi) Qinvse(freqi)];
                save([deblank(pathname) '.' num2str(freqi) '.pts.dat'],'datout','-ascii');
                save([deblank(pathname) '.' num2str(freqi) '.lin.dat'],'p','-ascii');
                save([deblank(pathname) '.' num2str(freqi) '.fqe.dat'],'fqe','-ascii');

            else
                disp('lt 2 pts');
            end
        end

        % Data vector
        d = Qinv;
        ld = log10(d);

        % Weight vector (standard dev)
        se = Qinvse;
        dmax = d+se;
        ldmax = log10(dmax);
        lQinvse = ldmax - ld;
        lw = 1./(lQinvse.^2);

        % Freq vector
        f = freqmid;
        lf = log10(f);

        % Get rid of NaN
        ldi = find(~isnan(ld)); ldn = ld(ldi);
        lfi = find(~isnan(lf)); lfn = lf(lfi);
        lwi = find(~isnan(lw)); lwn = lw(lwi);

        if length(ldn) > 2
            % Model matrix
            Gn = [(0*lfn)+1 lfn];

            % Invert
            %m = inv(Gn'*diag(lwn)*Gn)*Gn'*diag(lwn)*ldn;
            [m,mse,tote,Cov] = lscov(Gn,ldn,lwn);

            % Calculate weighted values
            %ldnp = diag(sqrt(lwn))*ldn;
            %Gnp = diag(sqrt(lwn))*Gn;

            if 0
            % Bootstrap to find confidence interval
            nsets = 1000;
            estldn = m(1)+(m(2)*lfn);
            resldn = ldn-estldn;
            %rerr = normrnd(0,(10/nsets),[4 nsets]);
            %rerr = normrnd(0,0,[4 nsets]);
            [out,sam] = bootstrp(nsets,[],resldn);
            mbs = NaN*ones(2,nsets);
            for i = 1:nsets
                mbs(:,i) = lscov(Gn,estldn+resldn(sam(:,i)),lwn(sam(:,i)));
            end

            % Create covariance matrix from bootstrap results
            mnorm = repmat(m,1,nsets) - mbs;
            Cov = (1/nsets)*(mnorm*mnorm');

            end
            % Create confidence region from covariance matrix
            n=100; p=0:pi/n:2*pi;
            [eigvec,eigval] = eig(Cov);
            xy = [cos(p'),sin(p')] * sqrt(eigval) * eigvec'; % Transformation
            x = xy(:,1);
            y = xy(:,2);

            k = sqrt(chi2inv(0.95,2));
            k = 1;
            x = m(1)+(k*x);
            y = m(2)+(k*y);
            E = [x y];

            %figure
            %errorbar(f,d,w); set(gca,'XScale','log','YScale','log'); xlim([0.1 10]);
            qo = 10^-m(1)
            n = -m(2)
            %figure
            %plot(lfn,ldn,'ob',lfn,m(1)+m(2).*lfn); title(fname);
            %pause

            if 0
            figure
            plot(10.^-mbs(1,:),-mbs(2,:),'+b',10.^-m(1),-m(2),'xr',10.^-x,-y,'-k'); xlim([0 500]); ylim([0 2]); title(fname);

            qo = 10^-m(1); qose = std(10.^-mbs(1,:));
            qoinv = 10^m(1); qoinvse = std(10.^mbs(1,:));
            n = -m(2); nse = std(-mbs(2,:));
            qfn = [qo n qose nse; qoinv n qoinvse nse; m(1) m(2) std(mbs(1,:)) std(mbs(2,:))];
            mbsout = [mbs(1,:)' mbs(2,:)'];
            ell = [x y];
            end

            qo = 10^-m(1); qose = (10^-m(1)) - (10^-(m(1)+mse(1)));
            qoinv = 10^m(1); qoinvse = (10^(m(1)+mse(1))) - (10^m(1));
            n = -m(2); nse = mse(2);
            qfn = [qo n qose nse; qoinv n qoinvse nse; m(1) m(2) mse(1) mse(2)];        
            ell = [x y];           
            fqw = [lfn ldn lwn];
            save([deblank(pathname) '.' deblank(dirname(diri,:)) '.qfn.dat'],'qfn','-ascii');
            %save([deblank(pathname) '.' deblank(dirname(diri,:)) '.pts.dat'],'mbsout','-ascii');
            save([deblank(pathname) '.' deblank(dirname(diri,:)) '.ell.dat'],'ell','-ascii');    
            save([deblank(pathname) '.' deblank(dirname(diri,:)) '.fqw.dat'],'fqw','-ascii');    
        end
        %close all
    end
    cd ..
end
